package com.jjt.calc.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.calc.domain.TwinFormulaInfo;

/**
 * 设备配方信息Mapper接口
 * 
 * @author wukai
 * @date 2025-01-18
 */
public interface TwinFormulaInfoMapper extends BaseMapper<TwinFormulaInfo>
{
    /**
     * 查询设备配方信息
     * 
     * @param specInfoId 设备配方信息主键
     * @return 设备配方信息
     */
    public TwinFormulaInfo selectTwinFormulaInfoBySpecInfoId(Long specInfoId);

    /**
     * 查询设备配方信息列表
     * 
     * @param twinFormulaInfo 设备配方信息
     * @return 设备配方信息集合
     */
    public List<TwinFormulaInfo> selectTwinFormulaInfoList(TwinFormulaInfo twinFormulaInfo);

    /**
     * 新增设备配方信息
     * 
     * @param twinFormulaInfo 设备配方信息
     * @return 结果
     */
    public int insertTwinFormulaInfo(TwinFormulaInfo twinFormulaInfo);

    /**
     * 修改设备配方信息
     * 
     * @param twinFormulaInfo 设备配方信息
     * @return 结果
     */
    public int updateTwinFormulaInfo(TwinFormulaInfo twinFormulaInfo);

    /**
     * 删除设备配方信息
     * 
     * @param specInfoId 设备配方信息主键
     * @return 结果
     */
    public int deleteTwinFormulaInfoBySpecInfoId(Long specInfoId);

    /**
     * 批量删除设备配方信息
     * 
     * @param specInfoIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinFormulaInfoBySpecInfoIds(Long[] specInfoIds);
}
